# Biomaj

Biomaj core library


Properties can be overriden by environment variables with pattern BIOMAJ_X_Y_Z for property x.y.z

Example:

use BIOMAJ_LDAP_HOST for ldap.host

[![PyPI version](https://badge.fury.io/py/biomaj-core.svg)](https://badge.fury.io/py/biomaj-core)
